package server

import (
	"errors"
	"fmt"
	"github.com/odysseus/nodemanager/config"
	"github.com/odysseus/nodemanager/server/apibackend"
	"net"

	omanager "github.com/odysseus/odysseus-protocol/gen/proto/go/nodemanager/v1"
	"google.golang.org/grpc"
)

var (
	ErrParams    = errors.New("invalid request")
	ErrUnSupport = errors.New("unsupport feature")
)

type NodeManagerService struct {
	backend apibackend.Backend
	quit    chan struct{}
	omanager.UnimplementedNodeManagerServiceServer
}

func registerService(server *grpc.Server) {
	bend := apibackend.NewBackend()
	omanager.RegisterNodeManagerServiceServer(server, &NodeManagerService{backend: bend, quit: make(chan struct{})})
}

func StartService() {
	lis, err := net.Listen("tcp", config.GetConfig().Endpoint)
	if err != nil {
		fmt.Printf("failed to listen: %v", err)
		return
	}
	s := grpc.NewServer(grpc.MaxSendMsgSize(1024*1024*20), grpc.MaxRecvMsgSize(1024*1024*20))
	registerService(s)

	err = s.Serve(lis)
	if err != nil {
		fmt.Printf("failed to serve: %v", err)
		return
	}
}
